summaryrefslogtreecommitdiffstats
path: root/src/doxygen.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/doxygen.h')
-rw-r--r--src/doxygen.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/doxygen.h b/src/doxygen.h
index 5f0f311..b35a04b 100644
--- a/src/doxygen.h
+++ b/src/doxygen.h
@@ -91,7 +91,7 @@ class Doxygen
static QIntDict<MemberGroupInfo> memGrpInfoDict;
static QDict<void> expandAsDefinedDict;
static NamespaceDef *globalScope;
- static QDict<RefList> *specialLists; // array of special lists: todo, test, bug, deprecated ...
+ static QDict<RefList> *xrefLists; // array of xref lists: todo, test, bug, deprecated ...
static QCString htmlFileExtension;
};